@@ -58,7 +58,8 @@ end
 # Calculate the vector of `df` rows hash values.
 function hashrows(cols::Tuple{Vararg{AbstractVector}}, skipmissing::Bool)
     len = length(cols[1])
-    rhashes = zeros(UInt, len)
+    ref_val = @static Base.VERSION >= v"1.13.0-DEV" ? Base.HASH_SEED : UInt(0)
+    rhashes = fill(ref_val, len)
     missings = fill(false, skipmissing ? len : 0)
     for (i, col) in enumerate(cols)
         rp = DataAPI.refpool(col)
